@@ -82,6 +82,13 @@ def parser_swagger(func, desc):
 
                         }
                     }
+                elif param_type == "boolean":
+                    schema["properties"][param.get("name", "")] = {
+                        "required": param.get("required", ""),
+                        "type": "boolean"
+                    }
+                if "default" in param:
+                    schema["properties"][param.get("name", "")]["default"] = param.get("default", "")
             param_list.append({
                 "required": True,
                 "name": "body",
@@ -141,6 +148,8 @@ def parser_swagger(func, desc):
 
                         }
                     }
+                if "default" in param:
+                    schema["properties"][param.get("name", "")]["default"] = param.get("default", "")
             param_list.append({
                 "required": True,
                 "name": "body",
