@@ -16,12 +16,22 @@ def get_basic_auth(username, password):
     return httpx.BasicAuth(username, password)
 
 
-async def common_request(method, path, params=None, data=None, json=None, base_url=options.data_server,
-                         result_type="json", pack=False, connect_config=None, **kwargs):
+async def common_request_origin(url, method, params=None, data=None, json=None, connect_config=None,
+                                **kwargs):
+    if not connect_config or not isinstance(connect_config, dict):
+        connect_config = {"timeout": None}
     try:
         httpx = importlib.import_module("httpx")
     except ImportError as e:
         raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+    with httpx.AsyncClient(**connect_config) as session:
+        async with session.request(method.upper(), url=url, params=params, json=json, data=data,
+                                   **kwargs) as resp:
+            return resp
+
+
+async def common_request(method, path, params=None, data=None, json=None, base_url=options.data_server,
+                         result_type="json", pack=False, connect_config=None, **kwargs):
     project_name = options.project_name.encode("utf-8")
     if not kwargs.get("headers"):
         kwargs.update({"headers": {
@@ -30,26 +40,24 @@ async def common_request(method, path, params=None, data=None, json=None, base_u
         }})
     else:
         kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
-    if not connect_config or not isinstance(connect_config, dict):
-        connect_config = {"timeout": None}
-    with httpx.AsyncClient(**connect_config) as session:
-        async with session.request(method.upper(), url=base_url + path, params=params, json=json, data=data,
-                                   **kwargs) as resp:
-            if result_type == "json":
-                result = await resp.json()
-                if not pack:
-                    if result.get("status") == "00000":
-                        result = result.get("data")
-                    else:
-                        message = f'ori_message:{result.get("status", "")}, {result.get("message", "未知错误")}'
-                        raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
-            elif result_type == "text":
-                result = await resp.text
-            elif result_type == "origin":
-                return resp
+
+    res = await common_request_origin(url=base_url + path, method=method, params=params, data=data, json=json,
+                                      connect_config=connect_config, **kwargs)
+    if result_type == "json":
+        res = await res.json()
+        if not pack:
+            if res.get("status") == "00000":
+                res = res.get("data")
             else:
-                result = await resp.content
-            return result
+                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
+                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
+    elif result_type == "text":
+        res = await res.text
+    elif result_type == "origin":
+        return res
+    else:
+        res = await res.content
+    return res
 
 
 async def post(path, data=None,
@@ -82,12 +90,24 @@ async def delete(path, params=None, data=None, json=None, base_url=options.data_
                                 result_type=result_type, pack=pack, **kwargs)
 
 
-def sync_common_request(method, path, params=None, data=None, json=None, base_url=None, result_type="json",
-                        pack=False, connect_config=None, **kwargs):
+def sync_common_request_origin(url, method, params=None, data=None, json=None, connect_config=None,
+                               **kwargs):
+    if not connect_config or not isinstance(connect_config, dict):
+        connect_config = {"timeout": None}
     try:
         httpx = importlib.import_module("httpx")
     except ImportError as e:
         raise Exception(f"httpx is not exist,run:pip install httpx==0.24.1")
+    with httpx.Client(**connect_config) as session:
+        try:
+            res = session.request(method.upper(), url=url, params=params, data=data, json=json, **kwargs)
+            return res
+        except Exception as e:
+            raise e
+
+
+def sync_common_request(method, path, params=None, data=None, json=None, base_url=None, result_type="json",
+                        pack=False, connect_config=None, **kwargs):
     project_name = options.project_name.encode("utf-8")
     if not base_url:
         base_url = options.data_server
@@ -98,28 +118,23 @@ def sync_common_request(method, path, params=None, data=None, json=None, base_ur
         }})
     else:
         kwargs["headers"].update({"Project-Name": project_name, "Request-Id": uuid.uuid1().hex})
-    if not connect_config or not isinstance(connect_config, dict):
-        connect_config = {"timeout": None}
-    with httpx.Client(**connect_config) as session:
-        try:
-            res = session.request(method.upper(), url=base_url + path, params=params, data=data, json=json, **kwargs)
-            if result_type == "json":
-                res = res.json()
-                if not pack:
-                    if res.get("status") == "00000":
-                        res = res.get("data")
-                    else:
-                        message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
-                        raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
-            elif result_type == "text":
-                res = res.text
-            elif result_type == "origin":
-                return res
+    res = sync_common_request_origin(url=base_url + path, method=method, params=params, data=data, json=json,
+                                     connect_config=connect_config, **kwargs)
+    if result_type == "json":
+        res = res.json()
+        if not pack:
+            if res.get("status") == "00000":
+                res = res.get("data")
             else:
-                res = res.content
-            return res
-        except Exception as e:
-            raise e
+                message = f'ori_message:{res.get("status", "")}, {res.get("message", "未知错误")}'
+                raise BusinessException(StatusCode.COMMON_CODE_MESSAGE("C0001", message))
+    elif result_type == "text":
+        res = res.text
+    elif result_type == "origin":
+        return res
+    else:
+        res = res.content
+    return res
 
 
 def sync_get(path, params=None, base_url=None, result_type="json", pack=False, connect_config=None, **kwargs):
