@@ -23,6 +23,7 @@ from lesscode.task.task_helper import TaskHelper
 from lesscode.utils.CacheUtil import async_common_cache, common_cache
 from lesscode.utils.es_log.record_log import es_record_log
 from lesscode.utils.json import JSONEncoder
+from lesscode.utils.request import sync_common_request_origin
 from lesscode.web.business_exception import BusinessException
 from lesscode.web.response_result import ResponseResult
 from lesscode.web.router_mapping import RouterMapping
@@ -253,7 +254,32 @@ class BaseHandler(RequestHandler):
                     else:
                         # params_list.append(parse_val(argument_value, parameter_type))
                         params_dict.update({parameter_name: parse_val(argument_value, parameter_type)})
-
+            title = handler_method.__cn_name__ or handler_method.__route_name__
+            if options.operate_log_enable:
+                _user = self.get_current_user()
+                _user_id = None
+                _username = None
+                _phone_no = None
+                if _user:
+                    _user_id = _user.id
+                    _username = _user.username
+                    _phone_no = _user.phone_no
+                try:
+                    _params = dict()
+                    for k, v in params_dict.items():
+                        if "self" != k:
+                            _params[k] = v
+                    res = sync_common_request_origin(url=options.write_operate_log_url, method="POST", json={
+                        "operate_action": title,
+                        "operate_url": self.request.path,
+                        "operate_user_id": _user_id,
+                        "operate_user_username": _username,
+                        "params": _params,
+                        "operate_user_phone_no": _phone_no
+                    })
+                    logging.info(f"添加操作日志成功，url:{self.request.path},title={title}")
+                except Exception as e:
+                    logging.error(f"添加操作日志失败，url={self.request.path},错误信息:{e}")
             # 判断是否为异步非阻塞方法，true 则直接调用
             try:
                 if inspect.iscoroutinefunction(handler_method):
