@@ -39,6 +39,8 @@ define("max_limit", default=500, type=int, help="单次查询最大数量")
 define("eureka_config", default={}, type=dict, help="eureka配置")
 define("rms_register_enable", default=False, type=bool, help="是否启动资源注册")
 define("rms_register_server", default="http://127.0.0.1:8918", type=str, help="启动资源注册")
+define("operate_log_enable", default=False, type=bool, help="记录操作日志开关，默认关闭")
+define("write_operate_log_url", default="http://127.0.0.1:8918", type=str, help="记录操作日志接口")
 define("running_env", default="local", type=str, help="运行环境")
 define("request_type", default="request", type=str, help="请求类型")
 define("db", default=None, type=object, help="SqlAlchemy")
